"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppTemplateBase = void 0;
class AppTemplateBase {
    constructor() {
        this.logger = this.createLogger();
        this.ioc = this.createIoc();
    }
    execute() {
        return __awaiter(this, void 0, void 0, function* () {
            this.logger.info("Application startup initiated.");
            try {
                yield this.initContainer();
                this.logger.info("Container initialization completed successfully.");
            }
            catch (error) {
                yield this.logger.error("Failed during container initialization: ", error);
                return;
            }
            this.logger.info("Application initialization started.");
            try {
                yield this.init();
                this.logger.info("Application initialization completed successfully.");
            }
            catch (error) {
                yield this.logger.error("Failed during application initialization: ", error);
                return;
            }
            this.logger.info("IOC container registration started.");
            try {
                yield this.register(this.ioc);
                this.logger.info("IOC container registration completed successfully.");
            }
            catch (error) {
                yield this.logger.error("Failed during IOC container registration: ", error);
                return;
            }
            this.logger.info("IOC container resolve started.");
            try {
                yield this.resolve(this.ioc);
                this.logger.info("IOC container resolve completed successfully.");
            }
            catch (error) {
                yield this.logger.error("Failed during IOC container resolve: ", error);
                return;
            }
            this.logger.info("Main application logic execution started.");
            try {
                yield this.main();
                this.logger.info("Main application logic execution completed successfully.");
            }
            catch (error) {
                yield this.logger.error("Failed during main application logic execution: ", error.stack);
                return;
            }
            this.logger.info("Application is running");
        });
    }
}
exports.AppTemplateBase = AppTemplateBase;
